@@ -1,19 +1,7 @@
-/*  Copyright (c) 2016 Klarälvdalens Datakonsult AB
-                  2017 Intevation GmbH
+/*  SPDX-FileCopyrightText: 2016 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2017 Intevation GmbH
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "certificatedetailswidget.h"
@@ -27,6 +15,7 @@
 #include "commands/changepassphrasecommand.h"
 #include "commands/changeexpirycommand.h"
 #include "commands/certifycertificatecommand.h"
+#include "commands/revokecertificationcommand.h"
 #include "commands/adduseridcommand.h"
 #include "commands/genrevokecommand.h"
 #include "commands/detailscommand.h"
@@ -347,7 +336,7 @@ void CertificateDetailsWidget::Private::userIDTableContextMenuRequested(const QP
 
     QMenu *menu = new QMenu(q);
     menu->addAction(QIcon::fromTheme(QStringLiteral("view-certificate-sign")),
-                    i18n("Certify ..."),
+                    i18n("Certify..."),
                     q, [this, userID]() {
         auto cmd = new Kleo::Commands::CertifyCertificateCommand(userID);
         ui.userIDTable->setEnabled(false);
@@ -359,6 +348,21 @@ void CertificateDetailsWidget::Private::userIDTableContextMenuRequested(const QP
         });
         cmd->start();
     });
+    if (Kleo::Commands::RevokeCertificationCommand::isSupported()) {
+        menu->addAction(QIcon::fromTheme(QStringLiteral("view-certificate-revoke")),
+                        i18n("Revoke Certification..."),
+                        q, [this, userID]() {
+            auto cmd = new Kleo::Commands::RevokeCertificationCommand(userID);
+            ui.userIDTable->setEnabled(false);
+            connect(cmd, &Kleo::Commands::RevokeCertificationCommand::finished,
+                    q, [this]() {
+                ui.userIDTable->setEnabled(true);
+                // Trigger an update when done
+                q->setKey(key);
+            });
+            cmd->start();
+        });
+    }
     connect(menu, &QMenu::aboutToHide, menu, &QObject::deleteLater);
     menu->popup(ui.userIDTable->viewport()->mapToGlobal(p));
 }
