@@ -1,38 +1,16 @@
 /*  view/nullpinwidget.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2017 Intevation GmbH
+    SPDX-FileCopyrightText: 2017 Intevation GmbH
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "nullpinwidget.h"
 
 #include "kleopatra_debug.h"
 
+#include "smartcard/netkeycard.h"
 #include "smartcard/readerstatus.h"
 
 #include <gpgme++/error.h>
@@ -81,6 +59,11 @@ NullPinWidget::NullPinWidget(QWidget *parent)
     vLay->addLayout(hLayBtn);
 }
 
+void NullPinWidget::setSerialNumber(const std::string &serialNumber)
+{
+    mSerialNumber = serialNumber;
+}
+
 void NullPinWidget::doChangePin(bool sigG)
 {
     auto ret = KMessageBox::warningContinueCancel(this,
@@ -98,14 +81,18 @@ void NullPinWidget::doChangePin(bool sigG)
         return;
     }
 
+    const auto nksCard = ReaderStatus::instance()->getCard<NetKeyCard>(mSerialNumber);
+    if (!nksCard) {
+        KMessageBox::error(this, i18n("Failed to find the NetKey card with the serial number: %1", QString::fromStdString(mSerialNumber)));
+        return;
+    }
+
     if (sigG) {
-        ReaderStatus::mutableInstance()
-        ->startSimpleTransaction("SCD PASSWD --nullpin PW1.CH.SIG",
-                                 this, "setSigGPinSettingResult");
+        ReaderStatus::mutableInstance()->startSimpleTransaction(
+            nksCard, "SCD PASSWD --nullpin PW1.CH.SIG", this, "setSigGPinSettingResult");
     } else {
-        ReaderStatus::mutableInstance()
-        ->startSimpleTransaction("SCD PASSWD --nullpin PW1.CH",
-                                 this, "setNksPinSettingResult");
+        ReaderStatus::mutableInstance()->startSimpleTransaction(
+            nksCard, "SCD PASSWD --nullpin PW1.CH", this, "setNksPinSettingResult");
     }
 }
 
