@@ -1,38 +1,16 @@
 /*  view/smartcardwidget.h
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2017 by Bundesamt für Sicherheit in der Informationstechnik
-    Software engineering by Intevation GmbH
+    SPDX-FileCopyrightText: 2017 Bundesamt für Sicherheit in der Informationstechnik
+    SPDX-FileContributor: Intevation GmbH
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "welcomewidget.h"
 
 #include <version-kleopatra.h>
+#include <Libkleo/GnuPG>
 
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -63,7 +41,11 @@ public:
         auto hLay = new QHBoxLayout;
 
         const QString welcome = i18nc("%1 is version", "Welcome to Kleopatra %1",
+#ifdef Q_OS_WIN
+                                      Kleo::gpg4winVersion());
+#else
                                       QStringLiteral(KLEOPATRA_VERSION_STRING));
+#endif
         const QString introduction = i18n("Kleopatra is a front-end for the crypto software <a href=\"https://gnupg.org\">GnuPG</a>.");
 
         const QString keyExplanation = i18n("For most actions you need either a public key (certificate) or your own private key.");
